%global base_name exec
%global short_name commons-%{base_name}

Name:           apache-commons-exec
Version:        1.3
Release:        %mkrel 14
Summary:        Java library to reliably execute external processes from within the JVM
Group:          Development/Java
License:        ASL 2.0
URL:            https://commons.apache.org/exec/
BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch

Source0:        https://www.apache.org/dist/commons/%{base_name}/source/%{short_name}-%{version}-src.tar.gz

BuildRequires:  maven-local
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.commons:commons-parent:pom:)
BuildRequires:  mvn(org.apache.maven.plugins:maven-antrun-plugin)

# Tests execute /usr/bin/ping
BuildRequires:  iputils

%description
Commons Exec is a library for dealing with external process execution and
environment management in Java.


%package javadoc
Summary:        Javadocs for %{name}

%description javadoc
This package contains the API documentation for %{name}.


%prep
%setup -q -n %{short_name}-%{version}-src

# Fix wrong end-of-line encoding
for file in LICENSE.txt NOTICE.txt RELEASE-NOTES.txt STATUS; do
  sed -i.orig "s/\r//" $file && \
  touch -r $file.orig $file && \
  rm $file.orig
done

# Shell scripts used for unit tests must be executable (see
# https://commons.apache.org/exec/faq.html#environment-testing)
chmod a+x src/test/scripts/*.sh


%mvn_file :%{short_name} %{short_name} %{name}


%build
# - Skip Exec57Test (it is unstable), see RHBZ #1202260
# - Skip Exec34Test/Exec41Test/Exec60Test ("socket: Operation not permitted" on Koji)
%mvn_build -- \
  -Dcommons.osgi.symbolicName=org.apache.commons.exec \
  -Dcommons.packageId=exec \
  -Dmaven.compiler.source=1.8 \
  -Dmaven.compiler.target=1.8 \
  -Dtest=\!org.apache.commons.exec.issues.Exec34Test,\!org.apache.commons.exec.issues.Exec41Test,\!org.apache.commons.exec.issues.Exec57Test,\!org.apache.commons.exec.issues.Exec60Test

%install
%mvn_install


%files -f .mfiles
%license LICENSE.txt NOTICE.txt
%doc STATUS RELEASE-NOTES.txt


%files javadoc -f .mfiles-javadoc
%license LICENSE.txt NOTICE.txt




%changelog
* Sun Jun 29 2025 umeabot <umeabot> 1.3-14.mga10
+ Revision: 2223098
- Mageia 10 Mass Rebuild

* Tue May 21 2024 ns80 <ns80> 1.3-13.mga10
+ Revision: 2065577
- rebuild for java 21

* Sat Apr 02 2022 umeabot <umeabot> 1.3-12.mga9
+ Revision: 1840687
- Mageia 9 Mass Rebuild

* Sun Aug 23 2020 neoclust <neoclust> 1.3-11.mga8
+ Revision: 1618217
- Fix build with java11

* Sat Feb 15 2020 umeabot <umeabot> 1.3-10.mga8
+ Revision: 1527596
- Mageia 8 Mass Rebuild

* Thu Jul 18 2019 daviddavid <daviddavid> 1.3-9.mga8
+ Revision: 1422325
- Rebuild to regenerate OSGi metadata

* Tue Sep 18 2018 umeabot <umeabot> 1.3-8.mga7
+ Revision: 1259569
- Mageia 7 Mass Rebuild

* Thu May 18 2017 neoclust <neoclust> 1.3-7.mga6
+ Revision: 1103049
- Rebuild against new apache-parent

* Sat Jun 25 2016 daviddavid <daviddavid> 1.3-6.mga6
+ Revision: 1037473
- Regenerate build-requires

* Wed Mar 02 2016 neoclust <neoclust> 1.3-5.mga6
+ Revision: 982353
- Second rebuild of the java stack

* Sun Feb 21 2016 neoclust <neoclust> 1.3-4.mga6
+ Revision: 975483
- First rebuild of the java stack
- sync package apache-commons-exec with fedora

* Sat Dec 19 2015 zezinho <zezinho> 1.3-1.mga6
+ Revision: 912261
- new version

* Sun Jan 18 2015 dmorgan <dmorgan> 1.2-3.mga5
+ Revision: 811341
- Disable tests

* Thu Jan 01 2015 pterjan <pterjan> 1.2-2.mga5
+ Revision: 807953
- Clean rebuild
- Sync with Fedora 21 (update to 1.2)

* Wed Oct 15 2014 umeabot <umeabot> 1.1-12.mga5
+ Revision: 738957
- Second Mageia 5 Mass Rebuild
+ tv <tv>
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.1-10.mga5
+ Revision: 677806
- Mageia 5 Mass Rebuild

* Tue May 27 2014 dmorgan <dmorgan> 1.1-9.mga5
+ Revision: 627043
- Add missing BRs

* Sat Oct 19 2013 umeabot <umeabot> 1.1-8.mga4
+ Revision: 529881
- Mageia 4 Mass Rebuild

* Sun Jul 14 2013 dmorgan <dmorgan> 1.1-7.mga4
+ Revision: 453999
- Replace maven BuildRequires with maven-local

* Fri Jan 11 2013 umeabot <umeabot> 1.1-6.mga3
+ Revision: 345713
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 08 2012 dmorgan <dmorgan> 1.1-5.mga3
+ Revision: 328239
- Build with maven 3

* Wed Apr 27 2011 dmorgan <dmorgan> 1.1-4.mga1
+ Revision: 92234
- Rebuild after bootstrapping
- imported package apache-commons-exec


* Mon Mar 07 2011 Tom Callaway <spot@fedoraproject.org> - 1.1-3
- fix maven fragment

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Dec 28 2010 Mohamed El Morabity <melmorabity@fedorapeople.org> - 1.1-1
- Update to 1.1

* Wed Sep 1 2010 Alexander Kurtakov <akurtako@redhat.com> 1.0.1-4
- BR iputils. Needed by tests.

* Wed Sep 1 2010 Alexander Kurtakov <akurtako@redhat.com> 1.0.1-3
- Change maven plugin names to the new ones.

* Wed Feb  3 2010 ELMORABITY Mohamed <melmorabity@fedoraproject.org> 1.0.1-2
- Add missing %%post/%%postun Requires
- Use macro %%{_mavendepmapfragdir} instead of %%{_datadir}/maven2/pom
- Unown directories %%{_mavenpomdir} and %%{_mavendepmapfragdir}

* Mon Jan 18 2010 ELMORABITY Mohamed <melmorabity@fedoraproject.org> 1.0.1-1
- Initial RPM release
